@@ -22,6 +22,15 @@
 //!     assert!((multivariate[0] - 141.91294525072763).abs() < 1e-13, "f(4, 5) incorrect");
 //!     assert!((multivariate[1] - 10.04041030906696).abs() < 1e-13, "df/dx(4, 5) incorrect");
 //!     assert!((multivariate[2] - 76.63232824725357).abs() < 1e-13, "df/dy(4, 5) incorrect");
+//!
+//!     // You may also use the new Const approach (both U* and Const<*> use the const generics)
+//!     let x: Hyperdual<f64, 3> = Hyperdual::from_slice(&[4.0, 1.0, 0.0]);
+//!     let y: Hyperdual<f64, 3> = Hyperdual::from_slice(&[5.0, 0.0, 1.0]);
+//!
+//!     let multivariate = x * x + (x * y).sin() + y.powi(3);
+//!     assert!((multivariate[0] - 141.91294525072763).abs() < 1e-13, "f(4, 5) incorrect");
+//!     assert!((multivariate[1] - 10.04041030906696).abs() < 1e-13, "df/dx(4, 5) incorrect");
+//!     assert!((multivariate[2] - 76.63232824725357).abs() < 1e-13, "df/dy(4, 5) incorrect");
 //! }
 //! ```
 //!
@@ -112,6 +121,7 @@ impl<T: Copy + Scalar, const N: usize> Hyperdual<T, N> {
     where
         F: Fn(&T) -> T,
     {
+        // TODO: improve, so the real does not get mapped
         let mut v = self.map(|x| f(&x));
         v[0] = r;
         Hyperdual(v)
@@ -252,7 +262,8 @@ impl<T: Copy + Scalar + PartialOrd, const N: usize> PartialOrd<T> for Hyperdual<
 
 macro_rules! impl_to_primitive {
     ($($name:ident, $ty:ty),*) => {
-        impl<T: Copy + Scalar + ToPrimitive, const N: usize> ToPrimitive for Hyperdual<T, N> {
+        impl<T: Copy + Scalar + ToPrimitive, const N: usize> ToPrimitive for Hyperdual<T, N>
+{
             $(
                 #[inline]
                 fn $name(&self) -> Option<$ty> {
@@ -267,7 +278,8 @@ macro_rules! impl_from_primitive {
     ($($name:ident, $ty:ty),*) => {
         impl<T: Copy + Scalar + FromPrimitive, const N: usize> FromPrimitive for Hyperdual<T, N>
             where
-                T: Zero {
+                T: Zero
+        {
             $(
                 #[inline]
                 fn $name(n: $ty) -> Option<Hyperdual<T,N>> {
@@ -412,8 +424,8 @@ impl<T: Copy + Scalar + Num, const N: usize> SubAssign<Self> for Hyperdual<T, N>
 impl<T: Copy + Scalar + Num, const N: usize> Mul<Self> for Hyperdual<T, N> {
     type Output = Self;
 
-    #[inline]
     #[allow(clippy::suspicious_arithmetic_impl)]
+    #[inline]
     fn mul(self, rhs: Self) -> Self {
         let mut v = self.zip_map(&rhs, |x, y| rhs.real() * x + self.real() * y);
         v[0] = self.real() * rhs.real();
@@ -871,18 +883,21 @@ where
 
     #[inline]
     fn asin(self) -> Self {
+        // TODO: implement inv
         let c = (T::one() - self.real().powi(2)).sqrt();
         self.map_dual(self.real().asin(), |x| *x / c)
     }
 
     #[inline]
     fn acos(self) -> Self {
+        // TODO: implement inv
         let c = (T::one() - self.real().powi(2)).sqrt();
         self.map_dual(self.real().acos(), |x| x.neg() / c)
     }
 
     #[inline]
     fn atan(self) -> Self {
+        // TODO: implement inv
         let c = T::one() + self.real().powi(2);
         self.map_dual(self.real().atan(), |x| *x / c)
     }
@@ -959,12 +974,12 @@ where
 
     #[inline]
     fn to_degrees(self) -> Self {
-        Hyperdual::from_real(self.real().to_degrees())
+        self.map_dual(self.real().to_degrees(), |x| x.to_degrees())
     }
 
     #[inline]
     fn to_radians(self) -> Self {
-        Hyperdual::from_real(self.real().to_radians())
+        self.map_dual(self.real().to_radians(), |x| x.to_radians())
     }
 }
 
@@ -1012,8 +1027,8 @@ pub fn hyperspace_from_vector<T: Copy + Scalar + Num + Zero, const D: usize, con
     SVector::<Hyperdual<T, D>, N>::from_row_slice(&space_slice)
 }
 
-pub fn vector_from_hyperspace<T: Scalar + Zero + Float, const DIM_VEC: usize, const DIM_HYPER: usize>(
-    x_dual: &SVector<DualN<T, DIM_HYPER>, DIM_VEC>,
-) -> SVector<T, DIM_VEC> {
+pub fn vector_from_hyperspace<T: Scalar + Zero + Float, const DIM_VECTOR: usize, const DIM_HYPER: usize>(
+    x_dual: &SVector<DualN<T, DIM_HYPER>, { DIM_VECTOR }>,
+) -> SVector<T, DIM_VECTOR> {
     x_dual.map(|x| x.real())
 }
